Kokkos Kernels documentation: Under Construction
================================================
.. toctree::
   :maxdepth: 2

   KokkosKernels GitHub Homepage <https://github.com/kokkos/kokkos-kernels>
   User Manual <https://github.com/kokkos/kokkos-kernels/wiki>
   Developer Docs <developer/index.rst>
